fireworks.examples.custom_firetasks.hello_world package — FireWorks 1.4.4 documentation

# fireworks.examples.custom_firetasks.hello_world package

## Submodules

## fireworks.examples.custom_firetasks.hello_world.hello_world_run module

## fireworks.examples.custom_firetasks.hello_world.hello_world_task module

class `fireworks.examples.custom_firetasks.hello_world.hello_world_task.` `HelloTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

## Module contents